# Tycho

Tycho is a change management service, with the ability to store
operational events and query them via tags or within time ranges.

Tycho provides the ability to describe relationships between events
as well, by specifying an ID of a parent event from which the child
event was spawned.

Tycho is a service from the orbital group at Zillow.
